# Welcome to xpersist's documentation!

xpersist provides custom caching utility functions in Python.

## Get in touch

- If you encounter any errors or problems with **xpersist**, please open an issue at the GitHub [main repository](http://github.com/NCAR/xpersist/issues).
- If you have a question like "How do I find x?", ask on [GitHub discussions](https://github.com/NCAR/xpersist/discussions). Please include a self-contained reproducible example if possible.

```{toctree}
---
maxdepth: 1
hidden:
---

tutorials/index.md
how-to/index.md
explanation/index.md
reference/index.md

```

```{toctree}
---
maxdepth: 2
caption: Contribute to xpersist
hidden:
---

contributing.md
changelog.md
GitHub Repo <https://github.com/NCAR/xpersist>
GitHub discussions <https://github.com/NCAR/xpersist/discussions>

```
